@@ -120,9 +120,9 @@ BUILDER_OPTS = {
 @click.option(
     "--custom-builder",
     default=None,
-    help="Specify alternative builder name which allows jupyter-book to use a builder"
-    "provided by an external extension. This can only be used when using"
-    "--builder=custom",
+    help="Specify alternative builder provided by Sphinx, including text and epub. "
+    "This can only be used with --builder=custom. Valid options listed at "
+    "https://www.sphinx-doc.org/en/master/man/sphinx-build.html",
 )
 @click.option(
     "-v", "--verbose", count=True, help="increase verbosity (can be repeated)"
@@ -250,7 +250,11 @@ def build(
                 )
             # TODO could also check/warn if the format is not set to jb-article/jb-book?
 
-        config_overrides["external_toc_path"] = toc.as_posix()
+        config_overrides["external_toc_path"] = (
+            toc.relative_to(PATH_SRC_FOLDER).as_posix()
+            if get_config_only
+            else toc.as_posix()
+        )
 
         # Builder-specific overrides
         if builder == "pdfhtml":
@@ -281,7 +285,7 @@ def build(
     if nitpick:
         config_overrides["nitpicky"] = True
 
-    # If we only wan config (e.g. for printing/validation), stop here
+    # If we only want config (e.g. for printing/validation), stop here
     if get_config_only:
         return (path_config, PATH_SRC_FOLDER, config_overrides)
 
@@ -458,17 +462,29 @@ def sphinx(ctx, path_source, config, toc):
     path_config, full_path_source, config_overrides = ctx.invoke(
         build, path_source=path_source, config=config, toc=toc, get_config_only=True
     )
-
-    sphinx_config, config_meta = get_final_config(
+    sphinx_config, _ = get_final_config(
         user_yaml=Path(path_config) if path_config else None,
         sourcedir=Path(full_path_source),
         cli_config=config_overrides,
     )
-    lines = []
+    lines = [
+        "###############################################################################",
+        "# Auto-generated by `jupyter-book config`",
+        "# If you wish to continue using _config.yml, make edits to that file and",
+        "# re-generate this one.",
+        "###############################################################################",
+    ]
     for key in sorted(sphinx_config):
         lines.append(f"{key} = {sphinx_config[key]!r}")
+    content = "\n".join(lines).rstrip() + "\n"
 
-    click.echo("\n".join(lines))
+    out_folder = Path(path_config).parent if path_config else Path(full_path_source)
+    existed = out_folder.joinpath("conf.py").exists()
+    out_folder.joinpath("conf.py").write_text(content, encoding="utf8")
+    click.secho(f"Wrote conf.py to {out_folder}", fg="green")
+    if not existed:
+        # indicate to pre-commit that the file changed
+        sys.exit(2)
 
 
 # utility functions
